# SNX Tray
Tray Icon for snx

## Intall 
``pip install snxtray``

## Configuration
`cat $HOME/.config/snxtray.json`
```json
{
  "server": "IP/URL",
  "cert": "path to cert",
  "keep_passwd": false
}
```

